OdaImage
========

.. currentmodule:: oda_api.plot_tools

.. autoclass:: OdaImage
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~OdaImage.show
      ~OdaImage.update

   .. rubric:: Methods Documentation

   .. automethod:: show
   .. automethod:: update
